from .calculation import (
    derivative,
    directional_derivative,
    partial_derivative,
    gradient
)

from . import ode
from . import optimization

__version__ = "0.5.1"
__license__ = "MIT"
__author__ = "Kiyuob Jung"
__email__ = "kyjung@msu.edu"

__all__ = [
    "derivative",
    "directional_derivative", 
    "partial_derivative",
    "gradient", 
    "ode",
    "optimization",
    "__version__"
]



class OptimizationResult:
    def __init__(self, solution, objective_function_value, iteration, history=None):
        self.x = solution 
        self.fun_val = objective_function_value
        self.k = iteration
        self.history = history